# py-mocp

## Description
This Python module implements unix socket client for MOC Player.
Also it containts a simple script to display OSD notifications on track changed.

## Usage:
```
user@localhost:~$ mocp-notify.py
```
